@@ -4,31 +4,29 @@
 //    (See accompanying file LICENSE_1_0.txt or copy at
 //          http://www.boost.org/LICENSE_1_0.txt)
 
-#include <boost/context/detail/config.hpp>
+#include "boost/context/execution_context.hpp"
 
-#if ! defined(BOOST_CONTEXT_NO_EXECUTION_CONTEXT)
+#include <boost/config.hpp>
 
-# include "boost/context/execution_context.hpp"
-
-# include <boost/config.hpp>
-
-# ifdef BOOST_HAS_ABI_HEADERS
-#  include BOOST_ABI_PREFIX
-# endif
+#ifdef BOOST_HAS_ABI_HEADERS
+# include BOOST_ABI_PREFIX
+#endif
 
+#if ! defined(BOOST_CONTEXT_NO_CXX11)
+# if (defined(BOOST_EXECUTION_CONTEXT) && (BOOST_EXECUTION_CONTEXT == 1))
 namespace boost {
 namespace context {
 namespace detail {
 
 thread_local
-detail::activation_record::ptr_t
-detail::activation_record::current_rec;
+activation_record::ptr_t
+activation_record::current_rec;
 
 // zero-initialization
 thread_local static std::size_t counter;
 
 // schwarz counter
-activation_record_initializer::activation_record_initializer() {
+activation_record_initializer::activation_record_initializer() noexcept {
     if ( 0 == counter++) {
         activation_record::current_rec.reset( new activation_record() );
     }
@@ -36,7 +34,8 @@ activation_record_initializer::activation_record_initializer() {
 
 activation_record_initializer::~activation_record_initializer() {
     if ( 0 == --counter) {
-        activation_record::current_rec.reset();
+        BOOST_ASSERT( activation_record::current_rec->is_main_context() );
+        delete activation_record::current_rec.detach();
     }
 }
 
@@ -50,9 +49,9 @@ execution_context::current() noexcept {
 }
 
 }}
+# endif
+#endif
 
 # ifdef BOOST_HAS_ABI_HEADERS
 #  include BOOST_ABI_SUFFIX
 # endif
-
-#endif
